AssetAge

Enum AssetAge 

pub enum AssetAge {
    Duration(Duration),
    Unspecified,
}
Defines the duration for which an Asset will remain cached after it’s user has stopped using it. The default is 1h (3600s).

Variants



Duration(Duration)

Asset will be cached for the specified duration



Unspecified

Asset will be cached until app is closed

Implementations

Source

impl AssetAge

pub fn zero() -> Self

Asset will be cleaned as soon as it stops being used.